@@ -100,7 +100,7 @@ class Item {
     // effects - Return the uid.  The returned string is guaranteed
     //		 to remain valid until the item is deleted.
 
-    void SetUid(char const*);
+    //void SetUid(char const*);
     // modifies - this
     // effects  - Sets uid to specified value.
 
@@ -227,4 +227,10 @@ class Appointment : public Item {
     intArray* alarms;		/* Alarm times */
 };
 
+// Inlined routines
+
+inline char const* Item::GetUid() const {
+    return uid;
+}
+
 #endif /* _ITEMH */
