@@ -655,6 +655,18 @@ method ItemWindow mvbob {} {}
 method ItemWindow mveob {} {}
 method ItemWindow deletekey {} {}
 
+# Cut selected text
+proc itemwindow_cut_selection {} {
+    global last_sel
+    tkCanvasCutRegion [$last_sel canvas]
+}
+
+# Insert selected text
+proc itemwindow_insert_selection {} {
+    global last_sel
+    tkCanvasPaste [$last_sel canvas]
+}
+
 # Proc to run itemwindow key binding after checking for writability
 proc itemwindow_mod {c args} {
     global last_sel
