@@ -40,7 +40,7 @@ class NoteList {name view} {
     # Establish bindings
     $name.c bind bg <1> [list $self new]
     bind $name.c <Configure> [list $self canvas_resize %w %h]
-    bindtags $name.c [list $name.c IcalItemEdit]
+    bindtags $name.c [list IcalUser $name.c IcalItemEditBindings IcalItem IcalCommand]
 
     # Handle triggers
     trigger on add	[list $self change]
@@ -48,6 +48,7 @@ class NoteList {name view} {
     trigger on change	[list $self change]
     trigger on text	[list $self textchange]
     trigger on flush	[list $self rescan]
+    trigger on midnight	[list $self rescan]
     trigger on reconfig	[list $self reconfig]
 }
 
@@ -68,6 +69,7 @@ method NoteList destructor {} {
     trigger remove change	[list $self change]
     trigger remove text		[list $self textchange]
     trigger remove flush	[list $self rescan]
+    trigger remove midnight	[list $self rescan]
     trigger remove reconfig	[list $self reconfig]
 
     # Trim item list
